*************
Reference/API
*************

This page gives an overview of all public pylira objects, functions and methods. All classes and functions
exposed in ``pylira.*`` namespace are public.


.. toctree::
   :maxdepth: 2

   core
   data
   utils
